@@ -224,28 +224,3 @@ class Adc(Device,trk.Trk):
     
 Manager.record_new_device_type('Adc', Adc)
 
-
-Manager.record_cfg_template('Adc', """{name}:
-  type: Adc
-  interface: Softing
-  identifier: PLC1                            # OPCUA Object Identifier
-  prefix: MAIN_FAST.adc                       # TO BE UPDATED OPCUA attribute prefix
-  simulated: false
-  ignored: false
-  address: {address}
-  simaddr: opc.tcp://134.171.57.209:4840       # Simulation address
-  mapfile: "{cfg_dir}/mapAdc.yml"      # TO BE UPDATED
-  fits_prefix: "ADC1"
-  ctrl_config:
-    latitude:              -0.429833092
-    longitude:             1.228800386
-    axes: ['adc1_motor1', 'adc1_motor2']
-
-  adc1_motor1:
-      prefix: "motor1"
-      cfgfile: "{cfg_dir}/adc1Motor1.yml" # TO BE UPDATED
-  adc1_motor2:
-      prefix: "motor2"
-      cfgfile: "{cfg_dir}/adc1Motor2.yml" # TO BE UPDATED
-""")
-
