@@ -182,14 +182,15 @@ class Device:
         
         
     @classmethod
-    def from_config(cl, file_name, cfg_name, key=None, fits_prefix=''):
+    def from_config(cl, file_name, cfg_name=None, key=None, fits_prefix=''):
         """ read a device configuration file and return a :class:`Device` like object to handle it 
         
         Args:
             file_name (str): relative path to a configuration file 
                       The path is relative to one of the directory defined in the
                       $RESPATH environmnet variable
-            cfg_name (str): The device name in the config file. 
+            cfg_name (str,None): The device name in the config file. 
+                      If None take the first device of the configuration file
                     
                 For instance in config file like
                     
@@ -207,6 +208,9 @@ class Device:
             fits_prefix (str, optional): The fits prefix string for this device
         """
         allconfig = io.load_config(file_name)
+        if cfg_name is None:
+            # get the first key 
+            cfg_name = next(iter(allconfig))
         try:
             config = allconfig[cfg_name]
         except KeyError:
