@@ -161,7 +161,11 @@ class RPC_ERROR:
 class LampStatInterface(Device.StatInterface):
     ERROR = ERROR
     SUBSTATE = SUBSTATE
-
+    
+    @nodealiasproperty("is_ready", ["substate"])
+    def is_ready(self, substate):
+        return substate in [self.SUBSTATE.NOTOP_READY_ON, self.SUBSTATE.NOTOP_READY_OFF]
+    
     @nodealiasproperty("is_off", ["substate"])
     def is_off(self, substate):
         return substate == Lamp.SUBSTATE.OP_OFF
@@ -239,28 +243,7 @@ class Lamp(Device):
         """ switch off the lamp """        
         self.rpc.rpcSwitchOff.rcall()
         
-            
-     
-    
 
 
-Manager.record_new_device_type('Lamp', Lamp)
 
-Manager.record_cfg_template('Lamp', """{name}:
-  type: Lamp
-  interface: Softing
-  identifier: PLC1                             # OPCUA Object Identifier
-  prefix: MAIN.Lamp1                           #  TO BE UPDATED  OPCUA attribute prefix
-  simulated: false
-  ignored: false
-  address: {address}      # TO BE UPDATED 
-  simaddr: opc.tcp://134.171.12.182:4840      # Simulation address
-  mapfile: "{cfg_dir}/mapLamp.yml"    #  TO BE UPDATED
-  fits_prefix: "LAMP1"
-  ctrl_config:
-    low_fault:        false                     # If T, signal is active low
-    low_on:           false                     # If T, signal is active low
-    low_switch:       false                     # If T, signal is active low
-    initial_state:    false
-    timeout:         2000
-""")
\ No newline at end of file
+Manager.record_new_device_type('Lamp', Lamp)
\ No newline at end of file
