@@ -486,56 +486,4 @@ class Motor(Device):
         apos = self.stat.pos_actual.get(data) 
         return abs(apos-pos)<tol
     
-Manager.record_new_device_type('Motor', Motor)
-
-Manager.record_cfg_template('Motor', """{name}:
-  type: Motor
-  interface: Softing
-  identifier: PLC1
-  prefix: MAIN.Motor1 # TO BE UPDATED  
-  simulated: false
-  ignored: false
-  address: {address}   # TO BE UPDATED 
-  simaddr: opc.tcp://127.0.0.1:7578
-  mapfile: "{cfg_dir}/mapMotor.yml"  # TO BE UPDATED 
-  fits_prefix: "MOT1"
-  ctrl_config:
-    velocity:              3.0
-    min_pos:               0.0
-    max_pos:               359.0
-    axis_type:             CIRCULAR
-    active_low_lstop:      false
-    active_low_lhw:        false
-    active_low_ref:        true
-    active_low_index:      false
-    active_low_uhw:        true
-    active_low_ustop:      false
-    brake:                 false
-    low_brake:             false
-    low_inpos:             false
-    backlash:              0.0
-    tout_init:             30000
-    tout_move:             120000
-    tout_switch:           10000
-  initialisation:
-      sequence: ['FIND_LHW', 'FIND_UHW', 'CALIB_ABS', 'END']
-      FIND_LHW:
-         value1: 4.0
-         value2: 4.0
-      FIND_UHW:
-         value1: 4.0
-         value2: 4.0
-      CALIB_ABS:
-         value1: 0.0
-         value2: 0.0
-      END:
-         value1: 0.0
-         value2: 0.0
-  positions:
-     posnames: ['ON', 'OFF']
-     tolerance: 1                              # Tolerance in UU
-     "ON": 30
-     "OFF": 100
-""")
-
-
+Manager.record_new_device_type('Motor', Motor)
\ No newline at end of file
