@@ -186,18 +186,3 @@ class Piezo(Device):
     
 
 Manager.record_new_device_type('Piezo', Piezo)
-
-Manager.record_cfg_template('Piezo', """{name}:
-  type: Piezo 
-  interface: Softing
-  identifier: PLC1                             # OPCUA Object Identifier
-  prefix: MAIN.Piezo1                        # TO BE UPDATED OPCUA attribute prefix
-  simulated: false
-  address: {address}     # TO BE UPDATED OPCUA server address 
-  simaddr: opc.tcp://134.171.2.213:7677
-  mapfile: "{cfg_dir}/mapPiezo.yml"  # TO BE UPDATED
-  fits_prefix: "OPTI1"
-  ctrl_config:
-     num_axis:      3
-     max_on:        180
-""")
\ No newline at end of file
