@@ -76,6 +76,12 @@ class FifoOneNode(NodeAlias):
     def fget(self, value):
         self.fifo.append(value)
         return self.fifo
+    
+    def clear(self, maxlen=None):
+        if maxlen is None:
+            self.fifo.clear()
+        else:            
+            self.fifo = deque([], maxlen)
 
 class FifoNodes(NodeAlias):
     """ This is an :class:`NodeAlias` returning at each get a :class:`collections.deque` 
@@ -111,13 +117,20 @@ class FifoNodes(NodeAlias):
         
     """
     def __init__(self, key, nodes, maxlen):        
-        super(FifoNodes, self).__init__(key, nodes)
+        super(FifoNodes, self).__init__(key, nodes)        
         self.fifo = deque([], maxlen)
                 
     def fget(self, *values):
         self.fifo.append(values)
         return self.fifo
-
+    
+    def clear(self, maxlen=None):
+        if maxlen is None:
+            self.fifo.clear()
+        else:
+            self.maxlen = maxlen
+            self.fifo = deque([], maxlen)
+        
 
 def setitem(d,k,v):
     d[k] = v
